import Taro from '@tarojs/taro'
import { getQueryString } from './codeSegment.js'

let appid
const logger = Taro.getRealtimeLogManager()

export default (url, options) => {
  const { params, skipError, header, ...leftOptions } = options || {}
  const queryStr = getQueryString(params)

  if (!appid) {
    const { miniProgram } = Taro.getAccountInfoSync()
    appid = miniProgram.appId
  }

  const urlWithParams = queryStr ? `${url}?${queryStr}` : url;
  // eslint-disable-next-line no-undef
  const nwUrl = `${HOST}/api/wx/${appid}${urlWithParams}`

  const authToken = Taro.getStorageSync('token')
  const tokenHeader = authToken ? { Authorization: authToken } : {}
  const nwHeader = {
    ...(header || {}),
    ...tokenHeader,
  }

  return new Promise((resolve, reject) => {
    Taro.request({
      ...leftOptions,
      url: nwUrl,
      header: nwHeader,
      success: (res) => {
        const { code, message, data, token } = res.data

        if (token || data?.token) {
          Taro.setStorage({ key: 'token', data: token || data?.token })
        }

        if (code === 1000) {
          resolve(data)

        } else {
          if (!skipError) {
            Taro.showToast({
              title: message || '网络异常',
              icon: 'none',
            })
          }
          reject(message?.indexOf('java') > -1 ? '系统内部错误' : message)
        }
      },

      fail: (err) => {
        console.error(err)
        const message = err.message || err.errMsg || err
        if (!skipError) {
          Taro.showToast({
            title: message,
            icon: 'none',
          })
        }
        reject(message)
      }
    })
  })
}



export function uploadFile (filePath) {

  const authToken = Taro.getStorageSync('token')
  const tokenHeader = authToken ? { 'Authorization': authToken } : {}

  return new Promise((resolve, reject) => {
    Taro.uploadFile({
      // eslint-disable-next-line no-undef
      url: `${HOST}/api/wx/image`,
      filePath,
      name: 'file',
      header: tokenHeader,
      success: (res) => {
        if (res.errMsg === 'uploadFile:ok') {
          const { code, message, data, token } = JSON.parse(res.data)

          if (token || data?.token) {
            Taro.setStorage({ key: 'token', data: token || data?.token })
          }
          if (code === 1000) {
            resolve(data)
          } else {
            console.error(res)
            logger.error("上传文件失败")
            logger.error(res)
            reject(message?.indexOf('java') > -1 ? '系统内部错误' : message)
          }
        } else {
          console.error(res)

          logger.error("上传文件失败")
          logger.error(res)

          reject(res.errMsg)
        }
      },
      fail: (err) => {
        console.error(err)

        logger.error("上传文件失败")
        logger.error(err)

        const message = err.message || err.errMsg || err
        reject(message)
      }
    })
  })
}
